==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1beta1CustomResourceValidationFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1beta1CustomResourceValidationFluentImpl<A extends V1beta1CustomResourceValidationFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1CustomResourceValidationFluent<A>{

    private V1beta1JSONSchemaPropsBuilder openAPIV3Schema;

    public V1beta1CustomResourceValidationFluentImpl(){
    }
    public V1beta1CustomResourceValidationFluentImpl(V1beta1CustomResourceValidation instance){
            this.withOpenAPIV3Schema(instance.getOpenAPIV3Schema());

    }

    
/**
 * This method has been deprecated, please use method buildOpenAPIV3Schema instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1JSONSchemaProps getOpenAPIV3Schema(){
            return this.openAPIV3Schema!=null?this.openAPIV3Schema.build():null;
    }

    public V1beta1JSONSchemaProps buildOpenAPIV3Schema(){
            return this.openAPIV3Schema!=null?this.openAPIV3Schema.build():null;
    }

    public A withOpenAPIV3Schema(V1beta1JSONSchemaProps openAPIV3Schema){
            _visitables.remove(this.openAPIV3Schema);
            if (openAPIV3Schema!=null){ this.openAPIV3Schema= new V1beta1JSONSchemaPropsBuilder(openAPIV3Schema); _visitables.add(this.openAPIV3Schema);} return (A) this;
    }

    public Boolean hasOpenAPIV3Schema(){
            return this.openAPIV3Schema != null;
    }

    public V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> withNewOpenAPIV3Schema(){
            return new OpenAPIV3SchemaNestedImpl();
    }

    public V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> withNewOpenAPIV3SchemaLike(V1beta1JSONSchemaProps item){
            return new OpenAPIV3SchemaNestedImpl(item);
    }

    public V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOpenAPIV3Schema(){
            return withNewOpenAPIV3SchemaLike(getOpenAPIV3Schema());
    }

    public V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOrNewOpenAPIV3Schema(){
            return withNewOpenAPIV3SchemaLike(getOpenAPIV3Schema() != null ? getOpenAPIV3Schema(): new V1beta1JSONSchemaPropsBuilder().build());
    }

    public V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOrNewOpenAPIV3SchemaLike(V1beta1JSONSchemaProps item){
            return withNewOpenAPIV3SchemaLike(getOpenAPIV3Schema() != null ? getOpenAPIV3Schema(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1CustomResourceValidationFluentImpl that = (V1beta1CustomResourceValidationFluentImpl) o;
            if (openAPIV3Schema != null ? !openAPIV3Schema.equals(that.openAPIV3Schema) :that.openAPIV3Schema != null) return false;
            return true;
    }


    public class OpenAPIV3SchemaNestedImpl<N> extends V1beta1JSONSchemaPropsFluentImpl<V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<N>> implements V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta1JSONSchemaPropsBuilder builder;
    
            OpenAPIV3SchemaNestedImpl(V1beta1JSONSchemaProps item){
                    this.builder = new V1beta1JSONSchemaPropsBuilder(this, item);
            }
            OpenAPIV3SchemaNestedImpl(){
                    this.builder = new V1beta1JSONSchemaPropsBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1CustomResourceValidationFluentImpl.this.withOpenAPIV3Schema(builder.build());
    }
    public N endOpenAPIV3Schema(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1CustomResourceValidationFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1beta1CustomResourceValidationFluentImpl<A extends V1beta1CustomResourceValidationFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1CustomResourceValidationFluent<A>{

    private V1beta1JSONSchemaPropsBuilder openAPIV3Schema;

    public V1beta1CustomResourceValidationFluentImpl(){
    }
    public V1beta1CustomResourceValidationFluentImpl(V1beta1CustomResourceValidation instance){
            this.withOpenAPIV3Schema(instance.getOpenAPIV3Schema());

    }

    
/**
 * This method has been deprecated, please use method buildOpenAPIV3Schema instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1JSONSchemaProps getOpenAPIV3Schema(){
            return this.openAPIV3Schema!=null?this.openAPIV3Schema.build():null;
    }

    public V1beta1JSONSchemaProps buildOpenAPIV3Schema(){
            return this.openAPIV3Schema!=null?this.openAPIV3Schema.build():null;
    }

    public A withOpenAPIV3Schema(V1beta1JSONSchemaProps openAPIV3Schema){
            _visitables.get("openAPIV3Schema").remove(this.openAPIV3Schema);
            if (openAPIV3Schema!=null){ this.openAPIV3Schema= new V1beta1JSONSchemaPropsBuilder(openAPIV3Schema); _visitables.get("openAPIV3Schema").add(this.openAPIV3Schema);} return (A) this;
    }

    public Boolean hasOpenAPIV3Schema(){
            return this.openAPIV3Schema != null;
    }

    public V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> withNewOpenAPIV3Schema(){
            return new OpenAPIV3SchemaNestedImpl();
    }

    public V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> withNewOpenAPIV3SchemaLike(V1beta1JSONSchemaProps item){
            return new OpenAPIV3SchemaNestedImpl(item);
    }

    public V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOpenAPIV3Schema(){
            return withNewOpenAPIV3SchemaLike(getOpenAPIV3Schema());
    }

    public V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOrNewOpenAPIV3Schema(){
            return withNewOpenAPIV3SchemaLike(getOpenAPIV3Schema() != null ? getOpenAPIV3Schema(): new V1beta1JSONSchemaPropsBuilder().build());
    }

    public V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<A> editOrNewOpenAPIV3SchemaLike(V1beta1JSONSchemaProps item){
            return withNewOpenAPIV3SchemaLike(getOpenAPIV3Schema() != null ? getOpenAPIV3Schema(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1CustomResourceValidationFluentImpl that = (V1beta1CustomResourceValidationFluentImpl) o;
            if (openAPIV3Schema != null ? !openAPIV3Schema.equals(that.openAPIV3Schema) :that.openAPIV3Schema != null) return false;
            return true;
    }


    public class OpenAPIV3SchemaNestedImpl<N> extends V1beta1JSONSchemaPropsFluentImpl<V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<N>> implements V1beta1CustomResourceValidationFluent.OpenAPIV3SchemaNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta1JSONSchemaPropsBuilder builder;
    
            OpenAPIV3SchemaNestedImpl(V1beta1JSONSchemaProps item){
                    this.builder = new V1beta1JSONSchemaPropsBuilder(this, item);
            }
            OpenAPIV3SchemaNestedImpl(){
                    this.builder = new V1beta1JSONSchemaPropsBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1CustomResourceValidationFluentImpl.this.withOpenAPIV3Schema(builder.build());
    }
    public N endOpenAPIV3Schema(){
            return and();
    }

}


}
